package com.jiuqi.util.chinese;

import java.io.Serializable;

class ChineseDigitUnit implements Cloneable, Serializable {
   private static final char[] SMALL_UNIT = new char[]{'十', '百', '千'};
   private static final char[] BIG_UNIT = new char[]{'拾', '佰', '仟'};
   private static final char[] LARGE_UNIT = new char[]{'万', '亿'};
   private static String bufferedUnit = null;
   private static String bufferedPower = null;
   private String power;

   public ChineseDigitUnit() {
      this.power = "1";
   }

   public ChineseDigitUnit(long power) {
      if (power < 0L) {
         power = -power;
      }

      long value;
      for(value = 1L; power >= 10L; value *= 10L) {
         power /= 10L;
      }

      this.power = String.valueOf(value);
   }

   public ChineseDigitUnit(String unit) {
      if (unit != null && unit.equals("")) {
         boolean digitString = isDigitString(unit);
         if (digitString) {
            StringBuffer sb = new StringBuffer("1");

            for(int i = 0; i < unit.length() - 1; ++i) {
               sb.append("0");
            }

            this.power = sb.toString();
         } else {
            try {
               this.power = valueOf(unit);
            } catch (NotValidChineseDigitUnitException var5) {
               throw new IllegalArgumentException("单位\"" + unit + "\"既不是一个有效的阿拉伯数字，也不是有效的中文数字单位！");
            }
         }

      } else {
         throw new IllegalArgumentException("字符串为null或者空字符串！");
      }
   }

   public long longValue() {
      return Long.parseLong(this.power);
   }

   public String chineseValue(boolean useBigChar) {
      return toChineseUnit(this.power, useBigChar);
   }

   public static String valueOf(String value) throws NotValidChineseDigitUnitException {
      if (value.equals(bufferedUnit)) {
         return bufferedPower;
      } else {
         long result = 0L;

         int thisUnit;
         for(int i = 0; i < value.length(); ++i) {
            thisUnit = value.charAt(i);
            int position = -1;

            int j;
            for(j = 0; j < SMALL_UNIT.length; ++j) {
               if (thisUnit == SMALL_UNIT[j]) {
                  position = j;
                  break;
               }
            }

            boolean var8;
            if (position != -1) {
               result += (long)(position + 1);
               var8 = true;
            } else {
               for(j = 0; j < BIG_UNIT.length; ++j) {
                  if (thisUnit == BIG_UNIT[j]) {
                     position = j;
                     break;
                  }
               }

               if (position != -1) {
                  result += (long)(position + 1);
                  var8 = true;
               } else {
                  for(j = 0; j < LARGE_UNIT.length; ++j) {
                     if (thisUnit == LARGE_UNIT[j]) {
                        position = j;
                        break;
                     }
                  }

                  if (position == -1) {
                     throw new NotValidChineseDigitUnitException("字符" + thisUnit + "不是一个合法的中文数字单位！");
                  }

                  result += (long)(4 * (position + 1));
                  var8 = true;
               }
            }
         }

         StringBuffer sb = new StringBuffer("1");

         for(thisUnit = 0; (long)thisUnit < result; ++thisUnit) {
            sb.append("0");
         }

         bufferedUnit = value;
         bufferedPower = sb.toString();
         return sb.toString();
      }
   }

   public static String toChineseUnit(String power, boolean useBigChar) {
      if (!isDigitString(power)) {
         throw new IllegalArgumentException("字符串\"" + power + "\"不是一个阿拉伯数字字符串！");
      } else {
         int pow = power.length();

         StringBuffer sb;
         for(sb = new StringBuffer(); pow > 8; pow -= 8) {
            sb.insert(0, LARGE_UNIT[1]);
         }

         while(pow > 4) {
            sb.insert(0, LARGE_UNIT[0]);
            pow -= 4;
         }

         if (pow > 1) {
            if (!useBigChar) {
               sb.insert(0, SMALL_UNIT[pow - 2]);
            } else {
               sb.insert(0, BIG_UNIT[pow - 2]);
            }
         }

         return sb.toString();
      }
   }

   static boolean isDigitString(String value) {
      for(int i = 0; i < value.length(); ++i) {
         char c = value.charAt(i);
         if (!Character.isDigit(c)) {
            return false;
         }
      }

      return true;
   }

   public static boolean isValidChineseDigitUnit(String value) {
      try {
         valueOf(value);
         return true;
      } catch (NotValidChineseDigitUnitException var1) {
         return false;
      }
   }

   public static boolean isLargeUnit(char value) {
      for(int i = 0; i < LARGE_UNIT.length; ++i) {
         if (value == LARGE_UNIT[i]) {
            return true;
         }
      }

      return false;
   }

   public Object clone() {
      return new ChineseDigitUnit(this.power);
   }

   public boolean equals(Object obj) {
      if (this == obj) {
         return true;
      } else if (!(obj instanceof ChineseDigitUnit)) {
         return false;
      } else {
         ChineseDigitUnit unit = (ChineseDigitUnit)obj;
         return this.power.equals(unit.power);
      }
   }

   public int hashCode() {
      int value = super.hashCode();
      if (this.power != null) {
         value ^= this.power.hashCode();
      }

      return value;
   }

   public String toString() {
      return this.chineseValue(false);
   }
}
